<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-zhichang

_✨ 有趣的职场人专属日历 ✨_

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/A-kirami/nonebot-plugin-moyu.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-60s">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-60s.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

<details>
  <summary>效果图</summary>

![example](https://github.com/Priopus/nonebot_plugin_zhichang/blob/main/images/8af5b7c09ab1dbd5a9edf66cb6d92d9d.png)

</details>

## 💿 安装

<details>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-zhichang

</details>

## 🎉 使用
### 指令表
| 指令  | 说明 |
|:-----:|:----:|
| 职场/职场日历 | 查看今天的职场人日历 |
| 职场/职场日历+设置 | 以连续对话的形式设置职场人日历的推送时间 |
| 职场/职场日历+设置 小时:分钟 | 设置职场人日历的推送时间 |
| 职场/职场日历+状态 | 查看本群的职场人日历状态 |
| 职场/职场日历+禁用 | 禁用本群的职场人日历推送 |

## 💡 鸣谢

### [A-kirami的摸鱼日历](https://github.com/A-kirami/nonebot-plugin-moyu)
### [techotaku39的60s日历](https://github.com/techotaku39/nonebot-plugin-60s)
本项目就是用以上大佬的项目改了几行代码，连说明文档也是（）
